require 'test/helper'

describe "Client" do
  before do
    @ctx   = Dim::Container.new(TestContext)
  end

  describe :run_command do
    it  "without --verbose param" do
      cmd = "cd /etc/puppet/repo && git fetch && git checkout -f origin/feature && puppet apply /etc/puppet/repo/manifests/site.pp"
      @ctx.client.run_command('feature').must_equal cmd
    end

    it  "with --verbose param" do
      @ctx.register(:run_options){ {:verbose => true} }
      cmd = "cd /etc/puppet/repo && git fetch && git checkout -f origin/feature && /etc/puppet/repo/bin/prepare_environment.rb && puppet apply -v /etc/puppet/repo/manifests/site.pp"
      @ctx.client.run_command('feature').must_equal cmd
    end
  end

  describe :local_run_params do
    it "always runs without --try option" do
      @ctx.register(:run_options){ {:try => false} }
      @ctx.client.local_run_params.must_equal ["run", "master"]
    end

    it "is nil with --try option" do
      @ctx.register(:run_options){ {:try => true} }
      @ctx.client.local_run_params.must_be_nil
    end
  end

  describe :remote_run_params do
    it "always runs without --try option" do
      @ctx.register(:run_options){ {:try => true} }
      @ctx.client.stubs(:remote_run_params).returns(["run", "master"])
      @ctx.client.calculate_run_params.must_equal ['run', 'master']
    end
  end
end
